@@ -19,12 +19,6 @@ def solr_url():
     return 'solr://127.0.0.1:8983/solr'
 
 
-@pytest.fixture
-def elasticsearch_url():
-    """Return Elasticsearch URL."""
-    return 'elasticsearch://127.0.0.1:9200/index'
-
-
 @pytest.fixture
 def whoosh_url():
     """Return Whoosh URL."""
